summaryrefslogtreecommitdiffstats
path: root/sbin/dump/main.c
diff options
context:
space:
mode:
authortrhodes <trhodes@FreeBSD.org>2002-05-16 04:10:46 +0000
committertrhodes <trhodes@FreeBSD.org>2002-05-16 04:10:46 +0000
commit896f3841bf047ca93766900f8cd8c5852e6a9245 (patch)
tree0adfec655f17ae1258112946fa8d7d72c9c75f76 /sbin/dump/main.c
parent0c40c9d08e198e96b30b9b27d5caea7fce0f7118 (diff)
downloadFreeBSD-src-896f3841bf047ca93766900f8cd8c5852e6a9245.zip
FreeBSD-src-896f3841bf047ca93766900f8cd8c5852e6a9245.tar.gz
more file system > filesystem
Diffstat (limited to 'sbin/dump/main.c')
-rw-r--r--sbin/dump/main.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/sbin/dump/main.c b/sbin/dump/main.c
index f97eec5..860457b 100644
--- a/sbin/dump/main.c
+++ b/sbin/dump/main.c
@@ -292,7 +292,7 @@ main(int argc, char *argv[])
* disk can be either the full special file name,
* the suffix of the special file name,
* the special name missing the leading '/',
* the file system name with or without the leading '/'.
*/
dt = fstabsearch(disk);
if (dt != NULL) {
@@ -301,7 +301,7 @@ main(int argc, char *argv[])
(void)strncpy(spcl.c_filesys, dt->fs_file, NAMELEN);
} else {
(void)strncpy(spcl.c_dev, disk, NAMELEN);
- (void)strncpy(spcl.c_filesys, "an unlisted file system",
+ (void)strncpy(spcl.c_filesys, "an unlisted filesystem",
NAMELEN);
}
spcl.c_dev[NAMELEN-1]='\0';
@@ -340,7 +340,7 @@ main(int argc, char *argv[])
if (fstat(diskfd, &sb) != 0)
err(X_STARTUP, "%s: stat", disk);
if (S_ISDIR(sb.st_mode))
- errx(X_STARTUP, "%s: unknown file system", disk);
+ errx(X_STARTUP, "%s: unknown filesystem", disk);
sync();
sblock = (struct fs *)sblock_buf;
bread(SBOFF, (char *) sblock, SBSIZE);
@@ -292,7 +292,7 @@ main(int argc, char *argv[])
* the suffix of the special file name,
* the special name missing the leading '/',
- * the file system name with or without the leading '/'.
+ * the filesystem name with or without the leading '/'.
*/
dt = fstabsearch(disk);
OpenPOWER on IntegriCloud